<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"    
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt">

<!-- (c) 2012, Trimble Navigation Limited. All rights reserved.                                -->
<!-- Permission is hereby granted to use, copy, modify, or distribute this style sheet for any -->
<!-- purpose and without fee, provided that the above copyright notice appears in all copies   -->
<!-- and that both the copyright notice and the limited warranty and restricted rights notice  -->
<!-- below appear in all supporting documentation.                                             -->

<!-- TRIMBLE NAVIGATION LIMITED PROVIDES THIS STYLE SHEET "AS IS" AND WITH ALL FAULTS.         -->
<!-- TRIMBLE NAVIGATION LIMITED SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF MERCHANTABILITY -->
<!-- OR FITNESS FOR A PARTICULAR USE. TRIMBLE NAVIGATION LIMITED DOES NOT WARRANT THAT THE     -->
<!-- OPERATION OF THIS STYLE SHEET WILL BE UNINTERRUPTED OR ERROR FREE.                        -->

<xsl:output method="html" omit-xml-declaration="no" encoding="utf-8"/>

<!-- Set the numeric display details i.e. decimal point, thousands separator etc -->
<xsl:variable name="DecPt" select="'.'"/>    <!-- Change as appropriate for US/European -->
<xsl:variable name="GroupSep" select="','"/> <!-- Change as appropriate for US/European -->
<!-- Also change decimal-separator & grouping-separator in decimal-format below 
     as appropriate for US/European output -->
<xsl:decimal-format name="Standard" 
                    decimal-separator="."
                    grouping-separator=","
                    infinity="Infinity"
                    minus-sign="-"
                    NaN="?"
                    percent="%"
                    per-mille="&#2030;"
                    zero-digit="0" 
                    digit="#" 
                    pattern-separator=";" />

<xsl:variable name="DecPl0" select="'#0'"/>
<xsl:variable name="DecPl1" select="concat('#0', $DecPt, '0')"/>
<xsl:variable name="DecPl2" select="concat('#0', $DecPt, '00')"/>
<xsl:variable name="DecPl3" select="concat('#0', $DecPt, '000')"/>
<xsl:variable name="DecPl4" select="concat('#0', $DecPt, '0000')"/>
<xsl:variable name="DecPl5" select="concat('#0', $DecPt, '00000')"/>
<xsl:variable name="DecPl6" select="concat('#0', $DecPt, '000000')"/>
<xsl:variable name="DecPl8" select="concat('#0', $DecPt, '00000000')"/>

<xsl:variable name="fileExt" select="'htm'"/>

<!-- User variable definitions - Appropriate fields are displayed on the       -->
<!-- Survey Controller screen to allow the user to enter specific values       -->
<!-- which can then be used within the style sheet definition to control the   -->
<!-- output data.                                                              -->
<!--                                                                           -->
<!-- All user variables must be identified by a variable element definition    -->
<!-- named starting with 'userField' (case sensitive) followed by one or more  -->
<!-- characters uniquely identifying the user variable definition.             -->
<!--                                                                           -->
<!-- The text within the 'select' field for the user variable description      -->
<!-- references the actual user variable and uses the '|' character to         -->
<!-- separate the definition details into separate fields as follows:          -->
<!-- For all user variables the first field must be the name of the user       -->
<!-- variable itself (this is case sensitive) and the second field is the      -->
<!-- prompt that will appear on the Survey Controller screen.                  -->
<!-- The third field defines the variable type - there are four possible       -->
<!-- variable types: Double, Integer, String and StringMenu.  These variable   -->
<!-- type references are not case sensitive.                                   -->
<!-- The fields that follow the variable type change according to the type of  -->
<!-- variable as follow:                                                       -->
<!-- Double and Integer: Fourth field = optional minimum value                 -->
<!--                     Fifth field = optional maximum value                  -->
<!--   These minimum and maximum values are used by the Survey Controller for  -->
<!--   entry validation.                                                       -->
<!-- String: No further fields are needed or used.                             -->
<!-- StringMenu: Fourth field = number of menu items                           -->
<!--             Remaining fields are the actual menu items - the number of    -->
<!--             items provided must equal the specified number of menu items. -->
<!--                                                                           -->
<!-- The style sheet must also define the variable itself, named according to  -->
<!-- the definition.  The value within the 'select' field will be displayed in -->
<!-- the Survey Controller as the default value for the item.                  -->
<xsl:variable name="userField1" select="'inlineTolerance|Tolerance for inline deltas|double|0.0|50.0'"/>
<xsl:variable name="inlineTolerance" select="0.3"/>
<xsl:variable name="userField2" select="'crosslineTolerance|Tolerance for crossline deltas|double|0.0|50.0'"/>
<xsl:variable name="crosslineTolerance" select="0.3"/>
<xsl:variable name="userField3" select="'outOfTolerancePtsOnly|Report out of tolerance points only|stringMenu|2|Yes|No'"/>
<xsl:variable name="outOfTolerancePtsOnly" select="'No'"/>

<!-- **************************************************************** -->
<!-- Set global variables from the Environment section of JobXML file -->
<!-- **************************************************************** -->
<xsl:variable name="DistUnit"   select="/JOBFile/Environment/DisplaySettings/DistanceUnits" />
<xsl:variable name="AngleUnit"  select="/JOBFile/Environment/DisplaySettings/AngleUnits" />
<xsl:variable name="CoordOrder" select="/JOBFile/Environment/DisplaySettings/CoordinateOrder" />
<xsl:variable name="TempUnit"   select="/JOBFile/Environment/DisplaySettings/TemperatureUnits" />
<xsl:variable name="PressUnit"  select="/JOBFile/Environment/DisplaySettings/PressureUnits" />

<!-- Setup conversion factor for coordinate and distance values -->
<!-- Dist/coord values in JobXML file are always in metres -->
<xsl:variable name="DistConvFactor">
  <xsl:choose>
    <xsl:when test="$DistUnit='Metres'">1.0</xsl:when>
    <xsl:when test="$DistUnit='InternationalFeet'">3.280839895</xsl:when>
    <xsl:when test="$DistUnit='USSurveyFeet'">3.2808333333357</xsl:when>
    <xsl:otherwise>1.0</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<!-- Setup conversion factor for angular values -->
<!-- Angular values in JobXML file are always in decimal degrees -->
<xsl:variable name="AngleConvFactor">
  <xsl:choose>
    <xsl:when test="$AngleUnit='DMSDegrees'">1.0</xsl:when>
    <xsl:when test="$AngleUnit='Gons'">1.111111111111</xsl:when>
    <xsl:when test="$AngleUnit='Mils'">17.77777777777</xsl:when>
    <xsl:otherwise>1.0</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<!-- Setup boolean variable for coordinate order -->
<xsl:variable name="NECoords">
  <xsl:choose>
    <xsl:when test="$CoordOrder='North-East-Elevation'">true</xsl:when>
    <xsl:when test="$CoordOrder='X-Y-Z'">true</xsl:when>
    <xsl:otherwise>false</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<!-- Setup conversion factor for pressure values -->
<!-- Pressure values in JobXML file are always in millibars (hPa) -->
<xsl:variable name="PressConvFactor">
  <xsl:choose>
    <xsl:when test="$PressUnit='MilliBar'">1.0</xsl:when>
    <xsl:when test="$PressUnit='InchHg'">0.029529921</xsl:when>
    <xsl:when test="$PressUnit='mmHg'">0.75006</xsl:when>
    <xsl:otherwise>1.0</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<xsl:variable name="product">
  <xsl:choose>
    <xsl:when test="JOBFile/@product"><xsl:value-of select="JOBFile/@product"/></xsl:when>
    <xsl:otherwise>Trimble Survey Controller</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<xsl:variable name="version">
  <xsl:choose>
    <xsl:when test="JOBFile/@productVersion"><xsl:value-of select="JOBFile/@productVersion"/></xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="format-number(JOBFile/@version div 100, $DecPl2, 'Standard')"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<xsl:variable name="schemaVersion">
  <xsl:choose>
    <xsl:when test="JOBFile/@productVersion"><xsl:value-of select="JOBFile/@version"/></xsl:when>
    <xsl:otherwise>3.0</xsl:otherwise>  <!-- JobXML file prior to schema definition - set to 3.0 (prior to initial v4.0 schema) -->
  </xsl:choose>
</xsl:variable>

<xsl:variable name="trackAzimuth">
  <xsl:call-template name="TrackAzimuthValue"/>
</xsl:variable>

<xsl:variable name="gridDefinitions">
  <xsl:call-template name="GetGridDefinitionDetails"/>
</xsl:variable>

<xsl:variable name="crookedLineFileNames">
  <xsl:call-template name="GetCrookedLineFileNames"/>
</xsl:variable>

<xsl:variable name="exclusionZoneFileNames">
  <xsl:call-template name="GetExclusionZoneFileNames"/>
</xsl:variable>


<!-- **************************************************************** -->
<!-- ************************** Main Loop *************************** -->
<!-- **************************************************************** -->
<xsl:template match="/" >
  <html>

  <font face="Arial">

  <title>Land Seismic Points Report</title>
  <h2>Land Seismic Points Report</h2>

  <!-- Set the font size for use in tables -->
  <style type="text/css">
    body, table, td, th
    {
      font-size:13px;
    }
    th.blackTitleLine {background-color: black; color: white}
    th.silverTitleLine {background-color: silver}
    td.redText {color: red; font: bold}
  </style>

  <head>
  </head>

  <body>
  <table border="0" width="100%" cellpadding="3">
    <tr>
      <th align="left" width="30%">Job name:</th>
      <td align="left" width="70%"><xsl:value-of select="JOBFile/@jobName"/></td>
    </tr>
    <xsl:if test="JOBFile/@TimeStamp != ''"> <!-- Date could be null in an updated job -->
      <tr>
        <th align="left">Creation date:</th>
        <td align="left"><xsl:value-of select="substring-before(JOBFile/@TimeStamp, 'T')"/></td>
      </tr>
    </xsl:if>
    <tr>
      <th align="left">Distance/Coord units:</th>
      <td align="left">
        <xsl:choose>
          <xsl:when test="$DistUnit = 'USSurveyFeet'">US Survey Feet</xsl:when>
          <xsl:when test="$DistUnit = 'InternationalFeet'">International Feet</xsl:when>
          <xsl:otherwise>Meters</xsl:otherwise>
        </xsl:choose>
      </td>
    </tr>
    <tr>
      <th align="left">Angle units:</th>
      <td align="left">
        <xsl:choose>
          <xsl:when test="$AngleUnit='DMSDegrees'">DMS Degrees</xsl:when>
          <xsl:when test="$AngleUnit='Gons'">Gons</xsl:when>
          <xsl:when test="$AngleUnit='Mils'">Mils</xsl:when>
          <xsl:otherwise>Decimal Degrees</xsl:otherwise>
        </xsl:choose>
      </td>
    </tr>
    <tr>
      <th align="left">Inline deltas tolerance:</th>
      <td align="left">
        <xsl:value-of select="format-number($inlineTolerance, $DecPl3, 'Standard')"/>
      </td>
    </tr>
    <tr>
      <th align="left">Crossline deltas tolerance:</th>
      <td align="left">
        <xsl:value-of select="format-number($crosslineTolerance, $DecPl3, 'Standard')"/>
      </td>
    </tr>
    <xsl:if test="count(msxsl:node-set($gridDefinitions)/grid) != 0">
      <xsl:for-each select="msxsl:node-set($gridDefinitions)/grid">
        <tr>
          <th align="left">
            <xsl:choose>
              <xsl:when test="position() = 1">
                <xsl:choose>
                  <xsl:when test="count(msxsl:node-set($gridDefinitions)/grid) = 1">Grid definition file used:</xsl:when>
                  <xsl:otherwise>Grid definition files used:</xsl:otherwise>
                </xsl:choose>
              </xsl:when>
              <xsl:otherwise>&#160;</xsl:otherwise>
            </xsl:choose>
          </th>
          <td align="left">
            <xsl:value-of select="file"/>
            <xsl:text> (Tracks: </xsl:text>
            <xsl:value-of select="tracks"/>
            <xsl:text>, Bins: </xsl:text>
            <xsl:value-of select="bins"/>
            <xsl:text>)</xsl:text>
          </td>
        </tr>
      </xsl:for-each>
    </xsl:if>
    <xsl:if test="count(msxsl:node-set($crookedLineFileNames)/file) != 0">
      <xsl:for-each select="msxsl:node-set($crookedLineFileNames)/file">
        <tr>
          <th align="left">
            <xsl:choose>
              <xsl:when test="position() = 1">
                <xsl:choose>
                  <xsl:when test="count(msxsl:node-set($crookedLineFileNames)/file) = 1">Crooked line file used:</xsl:when>
                  <xsl:otherwise>Crooked line files used:</xsl:otherwise>
                </xsl:choose>
              </xsl:when>
              <xsl:otherwise>&#160;</xsl:otherwise>
            </xsl:choose>
          </th>
          <td align="left">
            <xsl:value-of select="."/>
          </td>
        </tr>
      </xsl:for-each>
    </xsl:if>
    <xsl:if test="count(msxsl:node-set($exclusionZoneFileNames)/file) != 0">
      <xsl:for-each select="msxsl:node-set($exclusionZoneFileNames)/file">
        <tr>
          <th align="left">
            <xsl:choose>
              <xsl:when test="position() = 1">
                <xsl:choose>
                  <xsl:when test="count(msxsl:node-set($exclusionZoneFileNames)/file) = 1">Exclusion zone file used:</xsl:when>
                  <xsl:otherwise>Exclusion zone files used:</xsl:otherwise>
                </xsl:choose>
              </xsl:when>
              <xsl:otherwise>&#160;</xsl:otherwise>
            </xsl:choose>
          </th>
          <td align="left">
            <xsl:value-of select="."/>
          </td>
        </tr>
      </xsl:for-each>
    </xsl:if>
    <xsl:if test="string(number($trackAzimuth)) != 'NaN'">
      <tr>
        <th align="left">Track azimuth:</th>
        <td align="left">
          <xsl:call-template name="FormatAzimuth">
            <xsl:with-param name="theAzimuth" select="$trackAzimuth"/>
          </xsl:call-template>
        </td>
      </tr>
    </xsl:if>
  </table>
  
  <xsl:call-template name="SeparatingLine"/>
  <br/>
  <table border="1" width="100%" cellpadding="2">
    <thead>
      <xsl:choose>
        <xsl:when test="string(number($trackAzimuth)) != 'NaN'">
          <tr>
            <th class="silverTitleLine" width="30%">Point</th>
            <th class="silverTitleLine" width="30%">Code</th>
            <th class="silverTitleLine" width="20%">Inline</th>
            <th class="silverTitleLine" width="20%">Crossline</th>
          </tr>
        </xsl:when>
        <xsl:otherwise>
          <tr>
            <th class="silverTitleLine" width="25%">Point</th>
            <th class="silverTitleLine" width="25%">Code</th>
            <th class="silverTitleLine" width="16%">Inline</th>
            <th class="silverTitleLine" width="16%">Crossline</th>
            <th class="silverTitleLine" width="18%">Track Azimuth</th>
          </tr>
        </xsl:otherwise>
      </xsl:choose>
    </thead>
    <tbody>

      <!-- Process the non-deleted stakeout PointRecord elements in the FieldBook node -->
      <xsl:apply-templates select="JOBFile/FieldBook/PointRecord[(Deleted = 'false') and
                                                                 Stakeout and
                                                                 (Stakeout/PointDesign/StakeoutMethod = 'PointRelativeToAzimuth')]"/>

    </tbody>
  </table>
  </body>
  </font>
  </html>
</xsl:template>


<!-- **************************************************************** -->
<!-- ******************** PointRecord Output ************************ -->
<!-- **************************************************************** -->
<xsl:template match="PointRecord">

  <xsl:variable name="absInline" select="concat(substring('-',2 - (Stakeout/LinearDeltas/DeltaStation &lt; 0)), '1') * Stakeout/LinearDeltas/DeltaStation"/>
  <xsl:variable name="absCrossline" select="concat(substring('-',2 - (Stakeout/LinearDeltas/DeltaOffset &lt; 0)), '1') * Stakeout/LinearDeltas/DeltaOffset"/>

  <xsl:variable name="inlineOutOfTol">
    <xsl:choose>
      <xsl:when test="$absInline * $DistConvFactor &gt; $inlineTolerance">true</xsl:when>
      <xsl:otherwise>false</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="crosslineOutOfTol">
    <xsl:choose>
      <xsl:when test="$absCrossline * $DistConvFactor &gt; $crosslineTolerance">true</xsl:when>
      <xsl:otherwise>false</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:if test="($outOfTolerancePtsOnly = 'No') or
                (($outOfTolerancePtsOnly = 'Yes') and (($inlineOutOfTol = 'true') or ($crosslineOutOfTol = 'true')))">
    <tr>
      <!-- Point Name -->
      <td align="left">
        <xsl:value-of select="Name"/>
      </td>

      <!-- Point Code -->
      <td align="left">
        <xsl:choose>
          <xsl:when test="Code != ''">
            <xsl:value-of select="Code"/>
          </xsl:when>
          <xsl:otherwise>&#160;</xsl:otherwise>
        </xsl:choose>
      </td>

      <!-- Inline (delta station) value -->
      <xsl:choose>
        <xsl:when test="$inlineOutOfTol = 'true'">
          <td class="redText" align="right">
            <xsl:value-of select="format-number(Stakeout/LinearDeltas/DeltaStation * $DistConvFactor, $DecPl3, 'Standard')"/>
          </td>
        </xsl:when>
        <xsl:otherwise>
          <td align="right">
            <xsl:value-of select="format-number(Stakeout/LinearDeltas/DeltaStation * $DistConvFactor, $DecPl3, 'Standard')"/>
          </td>
        </xsl:otherwise>
      </xsl:choose>

      <!-- Crossline (delta offset) value -->
      <xsl:choose>
        <xsl:when test="$crosslineOutOfTol = 'true'">
          <td class="redText" align="right">
            <xsl:value-of select="format-number(Stakeout/LinearDeltas/DeltaOffset * $DistConvFactor, $DecPl3, 'Standard')"/>
          </td>
        </xsl:when>
        <xsl:otherwise>
          <td align="right">
            <xsl:value-of select="format-number(Stakeout/LinearDeltas/DeltaOffset * $DistConvFactor, $DecPl3, 'Standard')"/>
          </td>
        </xsl:otherwise>
      </xsl:choose>

      <xsl:if test="string(number($trackAzimuth)) = 'NaN'">
        <!-- Track (reference) azimuth value -->
        <td align="right">
          <xsl:call-template name="FormatAzimuth">
            <xsl:with-param name="theAzimuth" select="Stakeout/PointDesign/ReferenceAzimuth"/>
          </xsl:call-template>
        </td>
      </xsl:if>
    </tr>
  </xsl:if>
</xsl:template>


<!-- **************************************************************** -->
<!-- **** Return track azimuth if a single azimuth has been used **** -->
<!-- **************************************************************** -->
<xsl:template name="TrackAzimuthValue">

  <xsl:variable name="stakedPts">
    <xsl:for-each select="/JOBFile/FieldBook/PointRecord[(Deleted = 'false') and
                                                         Stakeout and
                                                         (Stakeout/PointDesign/StakeoutMethod = 'PointRelativeToAzimuth')]">
      <xsl:sort data-type="number" order="ascending" select="Stakeout/PointDesign/ReferenceAzimuth"/>

      <xsl:copy-of select="."/>
    </xsl:for-each>
  </xsl:variable>

  <xsl:if test="msxsl:node-set($stakedPts)/PointRecord[1]/Stakeout/PointDesign/ReferenceAzimuth =
                msxsl:node-set($stakedPts)/PointRecord[last()]/Stakeout/PointDesign/ReferenceAzimuth">
    <xsl:value-of select="msxsl:node-set($stakedPts)/PointRecord[1]/Stakeout/PointDesign/ReferenceAzimuth"/>
  </xsl:if>
</xsl:template>


<!-- **************************************************************** -->
<!-- ********** Return details of the grid definitions used ********* -->
<!-- **************************************************************** -->
<xsl:template name="GetGridDefinitionDetails">

  <xsl:variable name="gridDetails">
    <xsl:choose>
      <xsl:when test="$schemaVersion &gt; 5.56">
        <xsl:for-each select="/JOBFile/FieldBook/CustomEntityRecord[CustomContent/GridDefinition]">
          <xsl:element name="grid">
            <xsl:element name="file">
              <xsl:value-of select="CustomContent/GridDefinition/File"/>
            </xsl:element>
            <xsl:element name="tracks">
              <xsl:value-of select="concat(CustomContent/GridDefinition/Tracks/Minimum, ' - ',
                                           CustomContent/GridDefinition/Tracks/Maximum)"/>
            </xsl:element>
            <xsl:element name="bins">
              <xsl:value-of select="concat(CustomContent/GridDefinition/Bins/Minimum, ' - ',
                                           CustomContent/GridDefinition/Bins/Maximum)"/>
            </xsl:element>
          </xsl:element>
        </xsl:for-each>
      </xsl:when>
      
      <xsl:otherwise>
        <xsl:for-each select="/JOBFile/FieldBook/PointRecord[(Deleted = 'false') and
                                                             Stakeout and
                                                             (count(Notes/Note[contains(., 'Grid definition file:')]) != 0)]">
          <xsl:element name="grid">
            <xsl:element name="file">
              <xsl:value-of select="substring-after(Notes/Note[contains(., 'Grid definition file:')], 'Grid definition file: ')"/>
            </xsl:element>
            <xsl:element name="tracks">
              <xsl:value-of select="substring-after(Notes/Note[contains(., 'Tracks:')], 'Tracks: ')"/>
            </xsl:element>
            <xsl:element name="bins">
              <xsl:value-of select="substring-after(Notes/Note[contains(., 'Bins:')], 'Bins: ')"/>
            </xsl:element>
          </xsl:element>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:for-each select="msxsl:node-set($gridDetails)/grid">
    <xsl:variable name="gridFileName" select="file"/>
    <xsl:if test="count(preceding-sibling::grid[file = $gridFileName]) = 0">
      <xsl:copy-of select="."/>
    </xsl:if>
  </xsl:for-each>
</xsl:template>


<!-- **************************************************************** -->
<!-- ********* Get the names of the crooked line files used ********* -->
<!-- **************************************************************** -->
<xsl:template name="GetCrookedLineFileNames">

  <xsl:variable name="crookedLineFiles">
    <xsl:choose>
      <xsl:when test="$schemaVersion &gt; 5.56">
        <xsl:for-each select="/JOBFile/FieldBook/CustomEntityRecord[CustomContent/CrookedLineFile]">
          <xsl:element name="file">
            <xsl:value-of select="CustomContent/CrookedLineFile/File"/>
          </xsl:element>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:for-each select="/JOBFile/FieldBook/PointRecord[(Deleted = 'false') and
                                                             Stakeout and
                                                             (count(Notes/Note[contains(., 'Crooked line file:')]) != 0)]">
          <xsl:element name="file">
            <xsl:value-of select="substring-after(Notes/Note[contains(., 'Crooked line file:')], 'Crooked line file: ')"/>
          </xsl:element>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:for-each select="msxsl:node-set($crookedLineFiles)/file">
    <xsl:variable name="fileName" select="."/>
    <xsl:if test="count(preceding-sibling::file[. = $fileName]) = 0">
      <xsl:copy-of select="."/>
    </xsl:if>
  </xsl:for-each>
</xsl:template>


<!-- **************************************************************** -->
<!-- ******** Get the names of the exclusion zone files used ******** -->
<!-- **************************************************************** -->
<xsl:template name="GetExclusionZoneFileNames">

  <xsl:variable name="exclusionZoneFiles">
    <xsl:choose>
      <xsl:when test="$schemaVersion &gt; 5.56">
        <xsl:for-each select="/JOBFile/FieldBook/CustomEntityRecord[CustomContent/ExclusionZone]">
          <xsl:element name="file">
            <xsl:value-of select="CustomContent/ExclusionZone/File"/>
          </xsl:element>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:for-each select="/JOBFile/FieldBook/PointRecord[(Deleted = 'false') and
                                                             Stakeout and
                                                             (count(Notes/Note[contains(., 'Exclusion zone file:')]) != 0)]">
          <xsl:element name="file">
            <xsl:value-of select="substring-after(Notes/Note[contains(., 'Exclusion zone file:')], 'Exclusion zone file: ')"/>
          </xsl:element>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:for-each select="msxsl:node-set($exclusionZoneFiles)/file">
    <xsl:variable name="fileName" select="."/>
    <xsl:if test="count(preceding-sibling::file[. = $fileName]) = 0">
      <xsl:copy-of select="."/>
    </xsl:if>
  </xsl:for-each>
</xsl:template>


<!-- **************************************************************** -->
<!-- ****************** Separating Line Output ********************** -->
<!-- **************************************************************** -->
<xsl:template name="SeparatingLine">
  <hr/>
</xsl:template>


<!-- **************************************************************** -->
<!-- ************ Output Azimuth in Appropriate Format ************** -->
<!-- **************************************************************** -->
<xsl:template name="FormatAzimuth">
  <xsl:param name="theAzimuth"/>
  <xsl:param name="secDecPlaces" select="0"/>
  <xsl:param name="DMSOutput" select="'false'"/>  <!-- Can be used to force DMS output -->
  <xsl:param name="useSymbols" select="'true'"/>
  <xsl:param name="quadrantBearings" select="'false'"/>  <!-- Can be used to force quadrant bearing output -->
  <xsl:param name="impliedDecimalPt" select="'false'"/>
  <xsl:param name="northLbl" select="'N'"/>
  <xsl:param name="eastLbl" select="'E'"/>
  <xsl:param name="southLbl" select="'S'"/>
  <xsl:param name="westLbl" select="'W'"/>
  <xsl:param name="dmsSymbols">&#0176;'"</xsl:param>

  <xsl:choose>
    <xsl:when test="(/JOBFile/Environment/DisplaySettings/AzimuthFormat = 'QuadrantBearings') or ($quadrantBearings != 'false')">
      <xsl:call-template name="FormatQuadrantBearing">
        <xsl:with-param name="decimalAngle" select="$theAzimuth"/>
        <xsl:with-param name="secDecPlaces" select="$secDecPlaces"/>
        <xsl:with-param name="impliedDecimalPt" select="$impliedDecimalPt"/>
        <xsl:with-param name="northLbl" select="$northLbl"/>
        <xsl:with-param name="eastLbl" select="$eastLbl"/>
        <xsl:with-param name="southLbl" select="$southLbl"/>
        <xsl:with-param name="westLbl" select="$westLbl"/>
        <xsl:with-param name="dmsSymbols" select="$dmsSymbols"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="FormatAngle">
        <xsl:with-param name="theAngle" select="$theAzimuth"/>
        <xsl:with-param name="secDecPlaces" select="$secDecPlaces"/>
        <xsl:with-param name="DMSOutput" select="$DMSOutput"/>
        <xsl:with-param name="useSymbols" select="$useSymbols"/>
        <xsl:with-param name="impliedDecimalPt" select="$impliedDecimalPt"/>
        <xsl:with-param name="dmsSymbols" select="$dmsSymbols"/>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<!-- **************************************************************** -->
<!-- ******************* Format a Quadrant Bearing ****************** -->
<!-- **************************************************************** -->
<xsl:template name="FormatQuadrantBearing">
  <xsl:param name="decimalAngle"/>
  <xsl:param name="secDecPlaces" select="0"/>
  <xsl:param name="impliedDecimalPt" select="'false'"/>
  <xsl:param name="northLbl" select="'N'"/>
  <xsl:param name="eastLbl" select="'E'"/>
  <xsl:param name="southLbl" select="'S'"/>
  <xsl:param name="westLbl" select="'W'"/>
  <xsl:param name="dmsSymbols">&#0176;'"</xsl:param>

  <xsl:choose>
    <!-- Null azimuth value -->
    <xsl:when test="string(number($decimalAngle)) = 'NaN'">
      <xsl:value-of select="format-number($decimalAngle, $DecPl3, 'Standard')"/>  <!-- Use the defined null format output -->
    </xsl:when>
    <!-- There is an azimuth value -->
    <xsl:otherwise>
      <xsl:variable name="quadrantAngle">
        <xsl:if test="($decimalAngle &lt;= 90.0)">
          <xsl:value-of select="number ( $decimalAngle )"/>
        </xsl:if>
        <xsl:if test="($decimalAngle &gt; 90.0) and ($decimalAngle &lt;= 180.0)">
          <xsl:value-of select="number( 180.0 - $decimalAngle )"/>
        </xsl:if>
        <xsl:if test="($decimalAngle &gt; 180.0) and ($decimalAngle &lt; 270.0)">
          <xsl:value-of select="number( $decimalAngle - 180.0 )"/>
        </xsl:if>
        <xsl:if test="($decimalAngle &gt;= 270.0) and ($decimalAngle &lt;= 360.0)">
          <xsl:value-of select="number( 360.0 - $decimalAngle )"/>
        </xsl:if>
      </xsl:variable>

      <xsl:variable name="quadrantPrefix">
        <xsl:if test="($decimalAngle &lt;= 90.0) or ($decimalAngle &gt;= 270.0)"><xsl:value-of select="$northLbl"/></xsl:if>
        <xsl:if test="($decimalAngle &gt; 90.0) and ($decimalAngle &lt; 270.0)"><xsl:value-of select="$southLbl"/></xsl:if>
      </xsl:variable>

      <xsl:variable name="quadrantSuffix">
        <xsl:if test="($decimalAngle &lt;= 180.0)"><xsl:value-of select="$eastLbl"/></xsl:if>
        <xsl:if test="($decimalAngle &gt; 180.0)"><xsl:value-of select="$westLbl"/></xsl:if>
      </xsl:variable>

      <xsl:value-of select="$quadrantPrefix"/>
      <xsl:choose>
        <xsl:when test="$AngleUnit = 'DMSDegrees'">
          <xsl:call-template name="FormatDMSAngle">
            <xsl:with-param name="decimalAngle" select="$quadrantAngle"/>
            <xsl:with-param name="secDecPlaces" select="$secDecPlaces"/>
            <xsl:with-param name="impliedDecimalPt" select="$impliedDecimalPt"/>
            <xsl:with-param name="dmsSymbols" select="$dmsSymbols"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="FormatAngle">
            <xsl:with-param name="theAngle" select="$quadrantAngle"/>
            <xsl:with-param name="secDecPlaces" select="$secDecPlaces"/>
            <xsl:with-param name="impliedDecimalPt" select="$impliedDecimalPt"/>
            <xsl:with-param name="dmsSymbols" select="$dmsSymbols"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:value-of select="$quadrantSuffix"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<!-- **************************************************************** -->
<!-- ************ Output Angle in Appropriate Format **************** -->
<!-- **************************************************************** -->
<xsl:template name="FormatAngle">
  <xsl:param name="theAngle"/>
  <xsl:param name="secDecPlaces" select="0"/>
  <xsl:param name="DMSOutput" select="'false'"/>  <!-- Can be used to force DMS output -->
  <xsl:param name="useSymbols" select="'true'"/>
  <xsl:param name="impliedDecimalPt" select="'false'"/>
  <xsl:param name="gonsDecPlaces" select="5"/>    <!-- Decimal places for gons output -->
  <xsl:param name="decDegDecPlaces" select="5"/>  <!-- Decimal places for decimal degrees output -->
  <xsl:param name="outputAsMilligonsOrSecs" select="'false'"/>
  <xsl:param name="outputAsMilligonsOrSecsSqrd" select="'false'"/>
  <xsl:param name="dmsSymbols">&#0176;'"</xsl:param>

  <xsl:variable name="gonsDecPl">
    <xsl:choose>
      <xsl:when test="$gonsDecPlaces = 1"><xsl:value-of select="$DecPl1"/></xsl:when>
      <xsl:when test="$gonsDecPlaces = 2"><xsl:value-of select="$DecPl2"/></xsl:when>
      <xsl:when test="$gonsDecPlaces = 3"><xsl:value-of select="$DecPl3"/></xsl:when>
      <xsl:when test="$gonsDecPlaces = 4"><xsl:value-of select="$DecPl4"/></xsl:when>
      <xsl:when test="$gonsDecPlaces = 5"><xsl:value-of select="$DecPl5"/></xsl:when>
      <xsl:when test="$gonsDecPlaces = 6"><xsl:value-of select="$DecPl6"/></xsl:when>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="decDegDecPl">
    <xsl:choose>
      <xsl:when test="$decDegDecPlaces = 1"><xsl:value-of select="$DecPl1"/></xsl:when>
      <xsl:when test="$decDegDecPlaces = 2"><xsl:value-of select="$DecPl2"/></xsl:when>
      <xsl:when test="$decDegDecPlaces = 3"><xsl:value-of select="$DecPl3"/></xsl:when>
      <xsl:when test="$decDegDecPlaces = 4"><xsl:value-of select="$DecPl4"/></xsl:when>
      <xsl:when test="$decDegDecPlaces = 5"><xsl:value-of select="$DecPl5"/></xsl:when>
      <xsl:when test="$decDegDecPlaces = 6"><xsl:value-of select="$DecPl6"/></xsl:when>
    </xsl:choose>
  </xsl:variable>

  <xsl:choose>
    <!-- Null angle value -->
    <xsl:when test="string(number($theAngle))='NaN'">
      <xsl:value-of select="format-number($theAngle, $DecPl3, 'Standard')"/> <!-- Use the defined null format output -->
    </xsl:when>
    <!-- There is an angle value -->
    <xsl:otherwise>
      <xsl:choose>
        <xsl:when test="($AngleUnit = 'DMSDegrees') or not($DMSOutput = 'false')">
          <xsl:choose>
            <xsl:when test="$outputAsMilligonsOrSecs != 'false'">
              <xsl:value-of select="format-number($theAngle * $AngleConvFactor * 3600.0, '00.0', 'Standard')"/>
            </xsl:when>            
            <xsl:when test="$outputAsMilligonsOrSecsSqrd != 'false'">
              <xsl:value-of select="format-number($theAngle * $AngleConvFactor * 3600.0 * 3600.0, '00.000', 'Standard')"/>
            </xsl:when>            
            <xsl:otherwise>
              <xsl:call-template name="FormatDMSAngle">
                <xsl:with-param name="decimalAngle" select="$theAngle"/>
                <xsl:with-param name="secDecPlaces" select="$secDecPlaces"/>
                <xsl:with-param name="useSymbols" select="$useSymbols"/>
                <xsl:with-param name="impliedDecimalPt" select="$impliedDecimalPt"/>
                <xsl:with-param name="dmsSymbols" select="$dmsSymbols"/>
              </xsl:call-template>
            </xsl:otherwise>
          </xsl:choose>  
        </xsl:when>

        <xsl:otherwise>
          <xsl:variable name="fmtAngle">
            <xsl:choose>
              <xsl:when test="($AngleUnit = 'Gons') and ($DMSOutput = 'false')">
                <xsl:choose>
                  <xsl:when test="$outputAsMilligonsOrSecs != 'false'">
                    <xsl:value-of select="format-number($theAngle * $AngleConvFactor * 1000.0, $DecPl2, 'Standard')"/>
                  </xsl:when>
                  <xsl:when test="$outputAsMilligonsOrSecsSqrd != 'false'">
                    <xsl:value-of select="format-number($theAngle * $AngleConvFactor * 1000.0 * 1000.0, $DecPl4, 'Standard')"/>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:choose>
                      <xsl:when test="$secDecPlaces &gt; 0">  <!-- More accurate angle output required -->
                        <xsl:value-of select="format-number($theAngle * $AngleConvFactor, $DecPl8, 'Standard')"/>
                      </xsl:when>
                      <xsl:otherwise>
                        <xsl:value-of select="format-number($theAngle * $AngleConvFactor, $gonsDecPl, 'Standard')"/>
                      </xsl:otherwise>
                    </xsl:choose>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>

              <xsl:when test="($AngleUnit = 'Mils') and ($DMSOutput = 'false')">
                <xsl:choose>
                  <xsl:when test="$secDecPlaces &gt; 0">  <!-- More accurate angle output required -->
                    <xsl:value-of select="format-number($theAngle * $AngleConvFactor, $DecPl6, 'Standard')"/>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="format-number($theAngle * $AngleConvFactor, $DecPl4, 'Standard')"/>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>

              <xsl:when test="($AngleUnit = 'DecimalDegrees') and ($DMSOutput = 'false')">
                <xsl:choose>
                  <xsl:when test="$secDecPlaces &gt; 0">  <!-- More accurate angle output required -->
                    <xsl:value-of select="format-number($theAngle * $AngleConvFactor, $DecPl8, 'Standard')"/>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="format-number($theAngle * $AngleConvFactor, $decDegDecPl, 'Standard')"/>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>
            </xsl:choose>
          </xsl:variable>
          
          <xsl:choose>
            <xsl:when test="$impliedDecimalPt != 'true'">
              <xsl:value-of select="$fmtAngle"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="translate($fmtAngle, '.', '')"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<!-- **************************************************************** -->
<!-- ********************** Format a DMS Angle ********************** -->
<!-- **************************************************************** -->
<xsl:template name="FormatDMSAngle">
  <xsl:param name="decimalAngle"/>
  <xsl:param name="secDecPlaces" select="0"/>
  <xsl:param name="useSymbols" select="'true'"/>
  <xsl:param name="impliedDecimalPt" select="'false'"/>
  <xsl:param name="dmsSymbols">&#0176;'"</xsl:param>

  <xsl:variable name="degreesSymbol">
    <xsl:choose>
      <xsl:when test="$useSymbols = 'true'"><xsl:value-of select="substring($dmsSymbols, 1, 1)"/></xsl:when>  <!-- Degrees symbol ° -->
      <xsl:otherwise>
        <xsl:if test="$impliedDecimalPt != 'true'">.</xsl:if>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="minutesSymbol">
    <xsl:choose>
      <xsl:when test="$useSymbols = 'true'"><xsl:value-of select="substring($dmsSymbols, 2, 1)"/></xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="secondsSymbol">
    <xsl:choose>
      <xsl:when test="$useSymbols = 'true'"><xsl:value-of select="substring($dmsSymbols, 3, 1)"/></xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="sign">
    <xsl:if test="$decimalAngle &lt; '0.0'">-1</xsl:if>
    <xsl:if test="$decimalAngle &gt;= '0.0'">1</xsl:if>
  </xsl:variable>

  <xsl:variable name="posDecimalDegrees" select="number($decimalAngle * $sign)"/>

  <xsl:variable name="positiveDecimalDegrees">  <!-- Ensure an angle very close to 360° is treated as 0° -->
    <xsl:choose>
      <xsl:when test="(360.0 - $posDecimalDegrees) &lt; 0.00001">
        <xsl:value-of select="0"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$posDecimalDegrees"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="decPlFmt">
    <xsl:choose>
      <xsl:when test="$secDecPlaces = 0"><xsl:value-of select="''"/></xsl:when>
      <xsl:when test="$secDecPlaces = 1"><xsl:value-of select="'.0'"/></xsl:when>
      <xsl:when test="$secDecPlaces = 2"><xsl:value-of select="'.00'"/></xsl:when>
      <xsl:when test="$secDecPlaces = 3"><xsl:value-of select="'.000'"/></xsl:when>
      <xsl:when test="$secDecPlaces = 4"><xsl:value-of select="'.0000'"/></xsl:when>
      <xsl:when test="$secDecPlaces = 5"><xsl:value-of select="'.00000'"/></xsl:when>
      <xsl:when test="$secDecPlaces = 6"><xsl:value-of select="'.000000'"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="''"/></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="degrees" select="floor($positiveDecimalDegrees)"/>
  <xsl:variable name="decimalMinutes" select="number(number($positiveDecimalDegrees - $degrees) * 60 )"/>
  <xsl:variable name="minutes" select="floor($decimalMinutes)"/>
  <xsl:variable name="seconds" select="number(number($decimalMinutes - $minutes)*60)"/>

  <xsl:variable name="partiallyNormalisedMinutes">
    <xsl:if test="number(format-number($seconds, concat('00', $decPlFmt))) = 60"><xsl:value-of select="number($minutes + 1)"/></xsl:if>
    <xsl:if test="not(number(format-number($seconds, concat('00', $decPlFmt))) = 60)"><xsl:value-of select="$minutes"/></xsl:if>
  </xsl:variable>

  <xsl:variable name="normalisedSeconds">
    <xsl:if test="number(format-number($seconds, concat('00', $decPlFmt))) = 60"><xsl:value-of select="0"/></xsl:if>
    <xsl:if test="not(number(format-number($seconds, concat('00', $decPlFmt))) = 60)"><xsl:value-of select="$seconds"/></xsl:if>
  </xsl:variable>

  <xsl:variable name="partiallyNormalisedDegrees">
    <xsl:if test="format-number($partiallyNormalisedMinutes, '0') = '60'"><xsl:value-of select="number($degrees + 1)"/></xsl:if>
    <xsl:if test="not(format-number($partiallyNormalisedMinutes, '0') = '60')"><xsl:value-of select="$degrees"/></xsl:if>
  </xsl:variable>

  <xsl:variable name="normalisedDegrees">
    <xsl:if test="format-number($partiallyNormalisedDegrees, '0') = '360'"><xsl:value-of select="0"/></xsl:if>
    <xsl:if test="not(format-number($partiallyNormalisedDegrees, '0') = '360')"><xsl:value-of select="$partiallyNormalisedDegrees"/></xsl:if>
  </xsl:variable>

  <xsl:variable name="normalisedMinutes">
    <xsl:if test="format-number($partiallyNormalisedMinutes, '00') = '60'"><xsl:value-of select="0"/></xsl:if>
    <xsl:if test="not(format-number($partiallyNormalisedMinutes, '00') = '60')"><xsl:value-of select="$partiallyNormalisedMinutes"/></xsl:if>
  </xsl:variable>

  <xsl:if test="$sign = -1">-</xsl:if>
  <xsl:value-of select="format-number($normalisedDegrees, '0')"/>
  <xsl:value-of select="$degreesSymbol"/>
  <xsl:value-of select="format-number($normalisedMinutes, '00')"/>
  <xsl:value-of select="$minutesSymbol"/>
  <xsl:choose>
    <xsl:when test="$useSymbols = 'true'">
      <xsl:value-of select="format-number($normalisedSeconds, concat('00', $decPlFmt))"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="translate(format-number($normalisedSeconds, concat('00', $decPlFmt)), '.', '')"/>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="$secondsSymbol"/>
</xsl:template>


</xsl:stylesheet>
