<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"    
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt">

<!-- (c) 2012, Trimble Navigation Limited. All rights reserved.                                -->
<!-- Permission is hereby granted to use, copy, modify, or distribute this style sheet for any -->
<!-- purpose and without fee, provided that the above copyright notice appears in all copies   -->
<!-- and that both the copyright notice and the limited warranty and restricted rights notice  -->
<!-- below appear in all supporting documentation.                                             -->

<!-- TRIMBLE NAVIGATION LIMITED PROVIDES THIS STYLE SHEET "AS IS" AND WITH ALL FAULTS.         -->
<!-- TRIMBLE NAVIGATION LIMITED SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF MERCHANTABILITY -->
<!-- OR FITNESS FOR A PARTICULAR USE. TRIMBLE NAVIGATION LIMITED DOES NOT WARRANT THAT THE     -->
<!-- OPERATION OF THIS STYLE SHEET WILL BE UNINTERRUPTED OR ERROR FREE.                        -->

<xsl:output method="html" omit-xml-declaration="no" encoding="utf-8"/>

<!-- Set the numeric display details i.e. decimal point, thousands separator etc -->
<xsl:variable name="DecPt" select="'.'"/>    <!-- Change as appropriate for US/European -->
<xsl:variable name="GroupSep" select="','"/> <!-- Change as appropriate for US/European -->
<!-- Also change decimal-separator & grouping-separator in decimal-format below 
     as appropriate for US/European output -->
<xsl:decimal-format name="Standard" 
                    decimal-separator="."
                    grouping-separator=","
                    infinity="Infinity"
                    minus-sign="-"
                    NaN="?"
                    percent="%"
                    per-mille="&#2030;"
                    zero-digit="0" 
                    digit="#" 
                    pattern-separator=";" />

<xsl:variable name="DecPl0" select="'#0'"/>
<xsl:variable name="DecPl1" select="concat('#0', $DecPt, '0')"/>
<xsl:variable name="DecPl2" select="concat('#0', $DecPt, '00')"/>
<xsl:variable name="DecPl3" select="concat('#0', $DecPt, '000')"/>
<xsl:variable name="DecPl4" select="concat('#0', $DecPt, '0000')"/>
<xsl:variable name="DecPl5" select="concat('#0', $DecPt, '00000')"/>
<xsl:variable name="DecPl6" select="concat('#0', $DecPt, '000000')"/>
<xsl:variable name="DecPl8" select="concat('#0', $DecPt, '00000000')"/>

<xsl:variable name="fileExt" select="'htm'"/>

<!-- User variable definitions - Appropriate fields are displayed on the       -->
<!-- Survey Controller screen to allow the user to enter specific values       -->
<!-- which can then be used within the style sheet definition to control the   -->
<!-- output data.                                                              -->
<!--                                                                           -->
<!-- All user variables must be identified by a variable element definition    -->
<!-- named starting with 'userField' (case sensitive) followed by one or more  -->
<!-- characters uniquely identifying the user variable definition.             -->
<!--                                                                           -->
<!-- The text within the 'select' field for the user variable description      -->
<!-- references the actual user variable and uses the '|' character to         -->
<!-- separate the definition details into separate fields as follows:          -->
<!-- For all user variables the first field must be the name of the user       -->
<!-- variable itself (this is case sensitive) and the second field is the      -->
<!-- prompt that will appear on the Survey Controller screen.                  -->
<!-- The third field defines the variable type - there are four possible       -->
<!-- variable types: Double, Integer, String and StringMenu.  These variable   -->
<!-- type references are not case sensitive.                                   -->
<!-- The fields that follow the variable type change according to the type of  -->
<!-- variable as follow:                                                       -->
<!-- Double and Integer: Fourth field = optional minimum value                 -->
<!--                     Fifth field = optional maximum value                  -->
<!--   These minimum and maximum values are used by the Survey Controller for  -->
<!--   entry validation.                                                       -->
<!-- String: No further fields are needed or used.                             -->
<!-- StringMenu: Fourth field = number of menu items                           -->
<!--             Remaining fields are the actual menu items - the number of    -->
<!--             items provided must equal the specified number of menu items. -->
<!--                                                                           -->
<!-- The style sheet must also define the variable itself, named according to  -->
<!-- the definition.  The value within the 'select' field will be displayed in -->
<!-- the Survey Controller as the default value for the item.                  -->
<xsl:variable name="userField1" select="'trackBinNbrIn|Track and bin numbers in|stringMenu|2|Point name|Point code'"/>
<xsl:variable name="trackBinNbrIn" select="'Point name'"/>
<xsl:variable name="userField2" select="'inlineTolerance|Tolerance for inline deltas|double|0.0|50.0'"/>
<xsl:variable name="inlineTolerance" select="0.3"/>
<xsl:variable name="userField3" select="'crosslineTolerance|Tolerance for crossline deltas|double|0.0|50.0'"/>
<xsl:variable name="crosslineTolerance" select="0.3"/>

<!-- **************************************************************** -->
<!-- Set global variables from the Environment section of JobXML file -->
<!-- **************************************************************** -->
<xsl:variable name="DistUnit"   select="/JOBFile/Environment/DisplaySettings/DistanceUnits" />
<xsl:variable name="AngleUnit"  select="/JOBFile/Environment/DisplaySettings/AngleUnits" />
<xsl:variable name="CoordOrder" select="/JOBFile/Environment/DisplaySettings/CoordinateOrder" />
<xsl:variable name="TempUnit"   select="/JOBFile/Environment/DisplaySettings/TemperatureUnits" />
<xsl:variable name="PressUnit"  select="/JOBFile/Environment/DisplaySettings/PressureUnits" />

<!-- Setup conversion factor for coordinate and distance values -->
<!-- Dist/coord values in JobXML file are always in metres -->
<xsl:variable name="DistConvFactor">
  <xsl:choose>
    <xsl:when test="$DistUnit='Metres'">1.0</xsl:when>
    <xsl:when test="$DistUnit='InternationalFeet'">3.280839895</xsl:when>
    <xsl:when test="$DistUnit='USSurveyFeet'">3.2808333333357</xsl:when>
    <xsl:otherwise>1.0</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<!-- Setup conversion factor for angular values -->
<!-- Angular values in JobXML file are always in decimal degrees -->
<xsl:variable name="AngleConvFactor">
  <xsl:choose>
    <xsl:when test="$AngleUnit='DMSDegrees'">1.0</xsl:when>
    <xsl:when test="$AngleUnit='Gons'">1.111111111111</xsl:when>
    <xsl:when test="$AngleUnit='Mils'">17.77777777777</xsl:when>
    <xsl:otherwise>1.0</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<!-- Setup boolean variable for coordinate order -->
<xsl:variable name="NECoords">
  <xsl:choose>
    <xsl:when test="$CoordOrder='North-East-Elevation'">true</xsl:when>
    <xsl:when test="$CoordOrder='X-Y-Z'">true</xsl:when>
    <xsl:otherwise>false</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<!-- Setup conversion factor for pressure values -->
<!-- Pressure values in JobXML file are always in millibars (hPa) -->
<xsl:variable name="PressConvFactor">
  <xsl:choose>
    <xsl:when test="$PressUnit='MilliBar'">1.0</xsl:when>
    <xsl:when test="$PressUnit='InchHg'">0.029529921</xsl:when>
    <xsl:when test="$PressUnit='mmHg'">0.75006</xsl:when>
    <xsl:otherwise>1.0</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<xsl:variable name="product">
  <xsl:choose>
    <xsl:when test="JOBFile/@product"><xsl:value-of select="JOBFile/@product"/></xsl:when>
    <xsl:otherwise>Trimble Survey Controller</xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<xsl:variable name="version">
  <xsl:choose>
    <xsl:when test="JOBFile/@productVersion"><xsl:value-of select="JOBFile/@productVersion"/></xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="format-number(JOBFile/@version div 100, $DecPl2, 'Standard')"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<xsl:variable name="schemaVersion">
  <xsl:choose>
    <xsl:when test="JOBFile/@productVersion"><xsl:value-of select="JOBFile/@version"/></xsl:when>
    <xsl:otherwise>3.0</xsl:otherwise>  <!-- JobXML file prior to schema definition - set to 3.0 (prior to initial v4.0 schema) -->
  </xsl:choose>
</xsl:variable>

<xsl:variable name="gridDefinitions">
  <xsl:call-template name="GetGridDefinitionDetails"/>
</xsl:variable>

<xsl:variable name="nbrBinDigits">  <!-- Determine the number of bin digits used from the grid definition details -->
  <xsl:if test="count(msxsl:node-set($gridDefinitions)/grid) = 1">  <!-- A single grid definition file has been used -->
    <xsl:choose>
      <xsl:when test="msxsl:node-set($gridDefinitions)/grid[1]/bins != ''">
        <xsl:variable name="firstBin" select="substring-before(msxsl:node-set($gridDefinitions)/grid[1]/bins, ' - ')"/>
        <xsl:variable name="lastBin" select="substring-after(msxsl:node-set($gridDefinitions)/grid[1]/bins, ' - ')"/>
        <xsl:choose>
          <xsl:when test="string-length($firstBin) = string-length($lastBin)">
            <xsl:value-of select="string-length($firstBin)"/>
          </xsl:when>
          <xsl:otherwise>4</xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>4</xsl:otherwise>
    </xsl:choose>
  </xsl:if>
</xsl:variable>

<xsl:variable name="exclusionZoneFileNames">
  <xsl:call-template name="GetExclusionZoneFileNames"/>
</xsl:variable>


<!-- **************************************************************** -->
<!-- ************************** Main Loop *************************** -->
<!-- **************************************************************** -->
<xsl:template match="/" >
  <html>

  <font face="Arial">

  <title>Land Seismic Grid Staked Points</title>
  <h2>Land Seismic Grid Staked Points</h2>

  <!-- Set the font size for use in tables -->
  <style type="text/css">
    body, table, td, th
    {
      font-size:13px;
    }
    th.blackTitleLine {background-color: black; color: white}
    th.silverTitleLine {background-color: silver}
    td.redText {color: red; font: bold}
  </style>

  <head>
  </head>

  <body>
  <table border="0" width="100%" cellpadding="3">
    <tr>
      <th align="left" width="30%">Job name:</th>
      <td align="left" width="70%"><xsl:value-of select="JOBFile/@jobName"/></td>
    </tr>
    <xsl:if test="JOBFile/@TimeStamp != ''"> <!-- Date could be null in an updated job -->
      <tr>
        <th align="left">Creation date:</th>
        <td align="left"><xsl:value-of select="substring-before(JOBFile/@TimeStamp, 'T')"/></td>
      </tr>
    </xsl:if>
    <xsl:if test="count(msxsl:node-set($gridDefinitions)/grid) != 0">
      <xsl:for-each select="msxsl:node-set($gridDefinitions)/grid">
        <tr>
          <th align="left">
            <xsl:choose>
              <xsl:when test="position() = 1">
                <xsl:choose>
                  <xsl:when test="count(msxsl:node-set($gridDefinitions)/grid) = 1">Grid definition file used:</xsl:when>
                  <xsl:otherwise>Grid definition files used:</xsl:otherwise>
                </xsl:choose>
              </xsl:when>
              <xsl:otherwise>&#160;</xsl:otherwise>
            </xsl:choose>
          </th>
          <td align="left">
            <xsl:value-of select="file"/>
            <xsl:text> (Tracks: </xsl:text>
            <xsl:value-of select="tracks"/>
            <xsl:text>, Bins: </xsl:text>
            <xsl:value-of select="bins"/>
            <xsl:text>)</xsl:text>
          </td>
        </tr>
      </xsl:for-each>
    </xsl:if>
    <xsl:if test="count(msxsl:node-set($exclusionZoneFileNames)/file) != 0">
      <xsl:for-each select="msxsl:node-set($exclusionZoneFileNames)/file">
        <tr>
          <th align="left">
            <xsl:choose>
              <xsl:when test="position() = 1">
                <xsl:choose>
                  <xsl:when test="count(msxsl:node-set($exclusionZoneFileNames)/file) = 1">Exclusion zone file used:</xsl:when>
                  <xsl:otherwise>Exclusion zone files used:</xsl:otherwise>
                </xsl:choose>
              </xsl:when>
              <xsl:otherwise>&#160;</xsl:otherwise>
            </xsl:choose>
          </th>
          <td align="left">
            <xsl:value-of select="."/>
          </td>
        </tr>
      </xsl:for-each>
    </xsl:if>
  </table>
  
  <xsl:call-template name="SeparatingLine"/>
  <br/>
  
  <xsl:call-template name="ReportStakedPoints"/>
  
  </body>
  </font>
  </html>
</xsl:template>


<!-- **************************************************************** -->
<!-- ************* Report the staked points per track *************** -->
<!-- **************************************************************** -->
<xsl:template name="ReportStakedPoints">

  <xsl:variable name="stakedPts">
    <xsl:for-each select="/JOBFile/FieldBook/PointRecord[(Deleted = 'false') and
                                                         Stakeout/PointDesign/ReferenceAzimuth]">
      <xsl:variable name="trackBin">
        <xsl:choose>
          <xsl:when test="$trackBinNbrIn = 'Point name'">
            <xsl:value-of select="Name"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="Code"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:if test="string-length($trackBin) &gt; $nbrBinDigits">
        <xsl:copy>
          <xsl:copy-of select="* | @*"/>
          <xsl:element name="track">
            <xsl:value-of select="substring($trackBin, 1, string-length($trackBin) - $nbrBinDigits)"/>
          </xsl:element>
          <xsl:element name="bin">
            <xsl:value-of select="substring($trackBin, string-length($trackBin) - $nbrBinDigits + 1, $nbrBinDigits)"/>
          </xsl:element>

          <xsl:variable name="absInline" select="concat(substring('-',2 - (Stakeout/LinearDeltas/DeltaStation &lt; 0)), '1') * Stakeout/LinearDeltas/DeltaStation"/>
          <xsl:variable name="absCrossline" select="concat(substring('-',2 - (Stakeout/LinearDeltas/DeltaOffset &lt; 0)), '1') * Stakeout/LinearDeltas/DeltaOffset"/>
          <xsl:element name="inlineOutOfTol">
            <xsl:choose>
              <xsl:when test="$absInline * $DistConvFactor &gt; $inlineTolerance">true</xsl:when>
              <xsl:otherwise>false</xsl:otherwise>
            </xsl:choose>
          </xsl:element>
          <xsl:element name="crosslineOutOfTol">
            <xsl:choose>
              <xsl:when test="$absCrossline * $DistConvFactor &gt; $crosslineTolerance">true</xsl:when>
              <xsl:otherwise>false</xsl:otherwise>
            </xsl:choose>
          </xsl:element>
        </xsl:copy>
      </xsl:if>

    </xsl:for-each>
  </xsl:variable>
  
  <xsl:variable name="sortedStakedPts">
    <xsl:for-each select="msxsl:node-set($stakedPts)/*">
      <xsl:sort data-type="number" order="ascending" select="track"/>
      <xsl:sort data-type="number" order="ascending" select="bin"/>
      
      <xsl:copy-of select="."/>
    </xsl:for-each>
  </xsl:variable>
  
  <xsl:variable name="tracks">
    <xsl:for-each select="msxsl:node-set($sortedStakedPts)/*">
      <xsl:if test="(position() = 1) or (track != preceding-sibling::*[1]/track)">
        <xsl:element name="track">
          <xsl:value-of select="track"/>
        </xsl:element>
      </xsl:if>
    </xsl:for-each>
  </xsl:variable>
  
  <table border="0" cellpadding="2" width="100%">
    <caption align="top">
      <p align="left"><b>Points Staked:</b></p>
    </caption>

    <xsl:for-each select="msxsl:node-set($tracks)/track">
      <tr>
        <td width="10%">
          <xsl:text>Track: </xsl:text>
          <xsl:value-of select="."/>
        </td>
        <td width="90%">
          <xsl:text>Points: </xsl:text>
          <xsl:call-template name="BinSequenceList">
            <xsl:with-param name="stakedPts" select="$sortedStakedPts"/>
            <xsl:with-param name="track" select="."/>
          </xsl:call-template>
        </td>
      </tr>
    </xsl:for-each>
  </table>
  
  <xsl:if test="(count(msxsl:node-set($stakedPts)/*[(inlineOutOfTol = 'true') or (crosslineOutOfTol = 'true')]) != 0)">
    <xsl:call-template name="SeparatingLine"/>
    <br/>

    <table border="0" cellpadding="2" width="100%">
      <caption align="top">
        <p align="left"><b>Out of tolerance staked points:</b></p>
      </caption>

      <tr>
        <th class="silverTitleLine" width="30%">Point</th>
        <th class="silverTitleLine" width="30%">Code</th>
        <th class="silverTitleLine" width="20%">Inline</th>
        <th class="silverTitleLine" width="20%">Crossline</th>
      </tr>

      <xsl:for-each select="msxsl:node-set($stakedPts)/*[(inlineOutOfTol = 'true') or (crosslineOutOfTol = 'true')]">
        <tr>
          <!-- Point Name -->
          <td align="left">
            <xsl:value-of select="Name"/>
          </td>

          <!-- Point Code -->
          <td align="left">
            <xsl:choose>
              <xsl:when test="Code != ''">
                <xsl:value-of select="Code"/>
              </xsl:when>
              <xsl:otherwise>&#160;</xsl:otherwise>
            </xsl:choose>
          </td>

          <!-- Inline (delta station) value -->
          <xsl:choose>
            <xsl:when test="inlineOutOfTol = 'true'">
              <td class="redText" align="right">
                <xsl:value-of select="format-number(Stakeout/LinearDeltas/DeltaStation * $DistConvFactor, $DecPl3, 'Standard')"/>
              </td>
            </xsl:when>
            <xsl:otherwise>
              <td align="right">
                <xsl:value-of select="format-number(Stakeout/LinearDeltas/DeltaStation * $DistConvFactor, $DecPl3, 'Standard')"/>
              </td>
            </xsl:otherwise>
          </xsl:choose>

          <!-- Crossline (delta offset) value -->
          <xsl:choose>
            <xsl:when test="crosslineOutOfTol = 'true'">
              <td class="redText" align="right">
                <xsl:value-of select="format-number(Stakeout/LinearDeltas/DeltaOffset * $DistConvFactor, $DecPl3, 'Standard')"/>
              </td>
            </xsl:when>
            <xsl:otherwise>
              <td align="right">
                <xsl:value-of select="format-number(Stakeout/LinearDeltas/DeltaOffset * $DistConvFactor, $DecPl3, 'Standard')"/>
              </td>
            </xsl:otherwise>
          </xsl:choose>
        </tr>
      </xsl:for-each>
    </table>
  </xsl:if>
</xsl:template>


<!-- **************************************************************** -->
<!-- ****************** Separating Line Output ********************** -->
<!-- **************************************************************** -->
<xsl:template name="BinSequenceList">
  <xsl:param name="stakedPts"/>
  <xsl:param name="track"/>

  <xsl:variable name="tempBins">
    <xsl:for-each select="msxsl:node-set($stakedPts)/*">
      <xsl:if test="track = $track">
        <xsl:element name="bin">
          <xsl:value-of select="bin"/>
        </xsl:element>
      </xsl:if>
    </xsl:for-each>
  </xsl:variable>

  <xsl:variable name="bins">  <!-- Node set variable containing unique bin numbers -->
    <xsl:for-each select="msxsl:node-set($tempBins)/*">
      <xsl:variable name="bin" select="."/>
      <xsl:if test="count(preceding-sibling::*[. = $bin]) = 0">
        <xsl:copy-of select="."/>
      </xsl:if>
    </xsl:for-each>
  </xsl:variable>

  <xsl:for-each select="msxsl:node-set($bins)/bin">
    <xsl:choose>
      <xsl:when test="position() = 1">
        <xsl:value-of select="."/>
      </xsl:when>

      <xsl:when test="(position() = last()) and (position() != 1)">
        <xsl:variable name="prevInterval" select=". - preceding-sibling::*[1]"/>
        <xsl:variable name="prevPrevInterval" select="preceding-sibling::*[1] - preceding-sibling::*[2]"/>
        <xsl:if test="$prevPrevInterval != $prevInterval">
          <!-- Must be the end of a range - output a comma -->
          <xsl:text>,</xsl:text>
        </xsl:if>
        <xsl:value-of select="."/>
      </xsl:when>

      <xsl:otherwise>
        <xsl:variable name="prevInterval" select=". - preceding-sibling::*[1]"/>
        <xsl:variable name="nextInterval" select="following-sibling::*[1] - ."/>
        <xsl:variable name="prevPrevInterval" select="preceding-sibling::*[1] - preceding-sibling::*[2]"/>

        <xsl:choose>
          <xsl:when test="$prevInterval != $nextInterval">
            <!-- We need to do something special in this case -->
            <!-- If the prevPrevInterval is the same as the prevInterval then -->
            <!-- this indicates that we were in a range so write out the      -->
            <!-- current bin to end the range.                                -->
            <xsl:choose>
              <xsl:when test="$prevPrevInterval = $prevInterval">
                <xsl:value-of select="."/>
              </xsl:when>
              <xsl:otherwise>
                <!-- Output a comma then the bin number -->
                <xsl:text>,</xsl:text>
                <xsl:value-of select="."/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:when>
          <xsl:otherwise>
            <!-- Indicate a range of points -->
            <xsl:if test="(position() = 2) or ($prevPrevInterval != $prevInterval)">
              <xsl:text> - </xsl:text>
            </xsl:if>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:for-each>
</xsl:template>


<!-- **************************************************************** -->
<!-- ********** Return details of the grid definitions used ********* -->
<!-- **************************************************************** -->
<xsl:template name="GetGridDefinitionDetails">

  <xsl:variable name="gridDetails">
    <xsl:choose>
      <xsl:when test="$schemaVersion &gt; 5.56">
        <xsl:for-each select="/JOBFile/FieldBook/CustomEntityRecord[CustomContent/GridDefinition]">
          <xsl:element name="grid">
            <xsl:element name="file">
              <xsl:value-of select="CustomContent/GridDefinition/File"/>
            </xsl:element>
            <xsl:element name="tracks">
              <xsl:value-of select="concat(CustomContent/GridDefinition/Tracks/Minimum, ' - ',
                                           CustomContent/GridDefinition/Tracks/Maximum)"/>
            </xsl:element>
            <xsl:element name="bins">
              <xsl:value-of select="concat(CustomContent/GridDefinition/Bins/Minimum, ' - ',
                                           CustomContent/GridDefinition/Bins/Maximum)"/>
            </xsl:element>
          </xsl:element>
        </xsl:for-each>
      </xsl:when>

      <xsl:otherwise>
        <xsl:for-each select="/JOBFile/FieldBook/PointRecord[(Deleted = 'false') and
                                                             Stakeout and
                                                             (count(Notes/Note[contains(., 'Grid definition file:')]) != 0)]">
          <xsl:element name="grid">
            <xsl:element name="file">
              <xsl:value-of select="substring-after(Notes/Note[contains(., 'Grid definition file:')], 'Grid definition file: ')"/>
            </xsl:element>
            <xsl:element name="tracks">
              <xsl:value-of select="substring-after(Notes/Note[contains(., 'Tracks:')], 'Tracks: ')"/>
            </xsl:element>
            <xsl:element name="bins">
              <xsl:value-of select="substring-after(Notes/Note[contains(., 'Bins:')], 'Bins: ')"/>
            </xsl:element>
          </xsl:element>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:for-each select="msxsl:node-set($gridDetails)/grid">
    <xsl:variable name="gridFileName" select="file"/>
    <xsl:if test="count(preceding-sibling::grid[file = $gridFileName]) = 0">
      <xsl:copy-of select="."/>
    </xsl:if>
  </xsl:for-each>
</xsl:template>


<!-- **************************************************************** -->
<!-- ******** Get the names of the exclusion zone files used ******** -->
<!-- **************************************************************** -->
<xsl:template name="GetExclusionZoneFileNames">

  <xsl:variable name="exclusionZoneFiles">
    <xsl:choose>
      <xsl:when test="$schemaVersion &gt; 5.56">
        <xsl:for-each select="/JOBFile/FieldBook/CustomEntityRecord[CustomContent/ExclusionZone]">
          <xsl:element name="file">
            <xsl:value-of select="CustomContent/ExclusionZone/File"/>
          </xsl:element>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:for-each select="/JOBFile/FieldBook/PointRecord[(Deleted = 'false') and
                                                             Stakeout and
                                                             (count(Notes/Note[contains(., 'Exclusion zone file:')]) != 0)]">
          <xsl:element name="file">
            <xsl:value-of select="substring-after(Notes/Note[contains(., 'Exclusion zone file:')], 'Exclusion zone file: ')"/>
          </xsl:element>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:for-each select="msxsl:node-set($exclusionZoneFiles)/file">
    <xsl:variable name="fileName" select="."/>
    <xsl:if test="count(preceding-sibling::file[. = $fileName]) = 0">
      <xsl:copy-of select="."/>
    </xsl:if>
  </xsl:for-each>
</xsl:template>


<!-- **************************************************************** -->
<!-- ****************** Separating Line Output ********************** -->
<!-- **************************************************************** -->
<xsl:template name="SeparatingLine">
  <hr/>
</xsl:template>


</xsl:stylesheet>
